@@ -5,15 +5,17 @@ package threads::shared;  # but we're masquerading as threads::shared.pm
 # Compatibility with the standard threads::shared
 # Do everything by the book from now on
 
-$VERSION  = '0.07';
+$VERSION  = '0.08';
 $threads_shared = $threads_shared = 1;
 use strict;
 
 # Load only the stuff that we really need
 # Make sure we can die with lots of information
+# Make sure we can find out about blessed references correctly
 
 use load;
 use Carp ();
+use Scalar::Util qw(reftype);
 
 # If forks.pm is loaded
 #  Make sure we have a local copy of the base command handler on the client side
@@ -309,7 +311,7 @@ sub _remote {
 
     my $sub = shift;
     my $it  = shift;
-    my $ref = ref $it;
+    my $ref = reftype $it;
     my $object;
 
 # Obtain the object
